program NkMon;

{$IMPORTEDDATA OFF}
{$R *.RES}

uses NLib, NSys, NApp, NConf, NResource, MainForm, Monitor;

type
  TNkMonApp = class(TApp)
    procedure Init; override;
    destructor Destroy; override;
  end;

procedure TNkMonApp.Init;
var
  opt: WideChar;
begin
  ProfDir := GetEnv('NKTOOLSPROF');
  if ProfDir = '' then
    ProfDir := DirName(ProgPath)
  else
    ProfDir := JoinPath([ProfDir, 'nkmon']);

  with ArgParser do begin
    while GetOpt(opt) do
      case opt of
        'd': ProfDir := GetArg;
        'p':
          try
            Monitor.UdpReceiverPort := SInt(GetArg);
          except
            on EValueError do begin
              App.Error('invalid port');
              Exit;
            end;
          end;
      else
        Error('usage: nkmon [-d profdir] [-p port]');
        ExitCode := 1;
        Exit;
      end;
    Argv := Args;
  end;

  ProfDir := AbsPath(ProfDir);
  try
    with TListDir.Create(ProfDir) do
      Free;
  except
    on E: EOSError do
      App.Error(FormatException(E));
  end;

  Config := TConf.Create;
  Config.Read(ResourceText('CONFIG'));
  Config.LoadFromFile(JoinPath([ProfDir, 'position']));
  Config.LoadFromFile(JoinPath([ProfDir, 'config']));

  MainForm := TNkMonMainForm.Create;

  Run;
end;

destructor TNkMonApp.Destroy;
begin
  MainForm.Free;
  Config.Free;
end;

begin
  App := TNkMonApp.Create('NkMon');
  try
    try
      App.Init;
    except
      App.Fatal;
    end;
  finally
    App.Free;
  end;
end.
